@@ -1,7 +1,6 @@
 import numpy as np
 import math
 import numbers
-import cv2
 from . import maths as cc_maths
 # from .maths import convert_to_int_or_float, rint
 
@@ -696,16 +695,3 @@ class Range:
 
     def to_slice(self):
         return slice(self.start, self.stop, self.step)
-
-
-def read_image(directory, order='RGB'):
-    array_bgr = cv2.imread(directory, cv2.IMREAD_COLOR)
-    order_l = order.upper()
-    if order_l == 'RGB':
-        array_rgb = cv2.cvtColor(array_bgr, cv2.COLOR_BGR2RGB)
-        # array_rgb = array_bgr[:, :, slice(-1, -4, -1)]
-        return array_rgb
-    elif order_l == 'BGR':
-        return array_bgr
-    else:
-        raise ValueError('order')
