@@ -1,7 +1,7 @@
 import numpy as np
 from ..combinations import n_conditions_to_combinations, conditions_to_combinations
 from ..array import samples_in_arr1_are_in_arr2
-from ..Formatter import numeric_indexes_to_slice
+from ..format_args import numeric_indexes_to_slice
 
 
 def merge_axes(
